==> kraft_0.95.orig.tar.gz: kraft-0.95/README.md <==

# The Kraft Project

**Kraft is free software to help to handle documents like quotes and invoices
in your small business.**

It is a Qt/KF5 based desktop software with a strong focus on ease of use
and the just enough feature set for the use case. With Kraft, creating documents
will run smooth and free time for more enjoyable things than office work.

Check out the website http://volle-kraft-voraus.de for more information.

Kraft runs on your Linux desktop. No cloud involved, your data stays with you!

With Kraft, writing documents like quotes and invoices is very easy and fast.
Repeating tasks are supported, documents can be generated semi automatically,
ie. invoices from offers sent out before.

For efficient work, Kraft supports catalogs to organize materials and
template texts. It focuses on high quality printouts because paper is
still the main communication media in the small business world. However,
it also sends documents via email.

Kraft utilizes a bunch of very useful tools of the free softare world:
- KDE addressbook for customer management
- MySQL or alternatively SQLite for database support
- [ReportLab](http://www.reportlab.com/opensource/) for PDF generation:
- [ctemplate](https://github.com/OlafvdSpek/ctemplate) templating library.

## Interested?

[Install Kraft](http://volle-kraft-voraus.de/Main/Download) on your Linux desktop.

For questions and comments, please speak up. Check the [web site](http://volle-kraft-voraus.de/Main/Contribution)
for contact details.

Jun 2005-2020, Klaas Freitag <kraft@freisturz.de>

==> kraft_0.97.orig.tar.gz: kraft-0.97/README.md <==

# The Kraft Project

**Kraft is free software to help to handle documents like quotes and invoices
in your small business.**

It is a Qt/KF5 based desktop software with a strong focus on ease of use
and the just enough feature set for the use case. With Kraft, creating documents
will run smooth and free time for more enjoyable things than office work.

Check out the website http://volle-kraft-voraus.de for more information.

Kraft runs on your Linux desktop. No cloud involved, your data stays with you!

With Kraft, writing documents like quotes and invoices is very easy and fast.
Repeating tasks are supported, documents can be generated semi automatically,
ie. invoices from offers sent out before.

For efficient work, Kraft supports catalogs to organize materials and
template texts. It focuses on high quality printouts because paper is
still the main communication media in the small business world. However,
it also sends documents via email.

Kraft utilizes a bunch of very useful tools of the free softare world:
- KDE addressbook for customer management
- MySQL or alternatively SQLite for database support
- [WeasyPrint](https://weasyprint.org) or [ReportLab](http://www.reportlab.com/opensource/) for PDF generation.
- [Grantlee](https://github.com/steveire/grantlee) or [ctemplate](https://github.com/OlafvdSpek/ctemplate) templating library.

## Interested?

[Install Kraft](http://volle-kraft-voraus.de/Main/Download) on your Linux desktop.

For questions and comments, please speak up. Check the [web site](http://volle-kraft-voraus.de/Main/Contribution)
for contact details.

Jun 2005-2021, Klaas Freitag <kraft@freisturz.de>
